<!--
Copyright (c) ONNX Project Contributors

SPDX-License-Identifier: Apache-2.0
-->

# Working Groups

As described in the ONNX [governance](/community/readme.md#wg---working-groups), Working Groups (WGs) are temporary groups formed to address issues that cross SIG boundaries. Working Groups have a have a clear goal measured through specific deliverables and disband after the goal is achieved. Working groups do not own artifacts long term; they create specifications, recommendations, and/or code implementations for submission to the relevant SIGs for approval and acceptance.

## Proposing a new working group
New Working Groups are created when there is sufficient interest in a topic area and someone volunteers to be the chair for the group and submits a proposal to the steering committee. The chair facilitates the discussion and helps synthesize proposals and decisions.

## Joining a working group
Working Groups have most of their discussions on Slack. If you are interested in participating, please join the discussion in the respective Slack channels. Details about any upcoming meetings will also be shared in the Slack channel. Working Group artifacts can be found in the [working-groups repository](https://github.com/onnx/working-groups).

You can find the schedule of meetings on the [LF AI wiki](https://onnx.ai/calendar)

## Active working groups

The list of active working group is found [here](https://github.com/onnx/working-groups#active-working-groups).

## Completed working groups

The list of completed working group is found [here](https://github.com/onnx/working-groups#completed-working-groups).

## Inactive working groups

The list of inactive working group is found [here](https://github.com/onnx/working-groups#inactive-working-groups).
